| BetaDanish | R Documentation |
Density, distribution function, quantile function, hazard function, and random generation for the four-parameter Beta-Danish distribution.
dbetadanish(x, a, b, c, k, log = FALSE)
pbetadanish(q, a, b, c, k, lower.tail = TRUE, log.p = FALSE)
qbetadanish(p, a, b, c, k, lower.tail = TRUE, log.p = FALSE)
rbetadanish(n, a, b, c, k)
hbetadanish(x, a, b, c, k, log = FALSE)
x, q |
Vector of quantiles (time points). |
a |
Shape parameter (beta generator). Set 'a = 1' for the 3-parameter submodel. |
b |
Shape parameter (beta generator / tail weight). |
c |
Shape parameter (baseline shape). |
k |
Scale parameter (baseline scale). |
log, log.p |
Logical; if TRUE, probabilities/densities are given as log. |
lower.tail |
Logical; if TRUE (default), probabilities are P[X <= x], otherwise P[X > x]. |
p |
Vector of probabilities. |
n |
Number of observations to generate. |
The Beta-Danish distribution is a highly flexible lifetime distribution capable of modeling decreasing, increasing, unimodal, and bathtub-shaped hazard rates.
'dbetadanish' gives the density, 'pbetadanish' gives the distribution function, 'qbetadanish' gives the quantile function, 'hbetadanish' gives the hazard function, and 'rbetadanish' generates random deviates.
Ahmad, B., & Danish, M. Y. (2026). Development and Characterization of a Flexible Three-Parameter Lifetime Distribution.
# Density
dbetadanish(x = 2, a = 1.5, b = 2, c = 3, k = 0.5)
# CDF
pbetadanish(q = 2, a = 1.5, b = 2, c = 3, k = 0.5)
# Hazard
hbetadanish(x = 2, a = 1.5, b = 2, c = 3, k = 0.5)
# Random generation
rbetadanish(n = 10, a = 1.5, b = 2, c = 3, k = 0.5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.