\(\tau_{r,s,w} = E\{Z^r F(Z)^s (1 - F(Z))^w\}\).
Details
Existence follows the same rule as the raw moments in the worst case, \(b > r\), and the weights can only reduce the tail contribution.
Examples
# tau_{1,0,0} is the mean
bd_pwm(1, 0, 0, a = 1.5, b = 3, c = 2, k = 1)
#> [1] 1.84375
bd_moments(1, a = 1.5, b = 3, c = 2, k = 1)
#> [1] 1.84375
bd_pwm(1, 1, 0, a = 1.5, b = 3, c = 2, k = 1)
#> [1] 1.355136