brain_cancer: Brain Cancer Survival Data

brain_cancerR Documentation

Brain Cancer Survival Data

Description

A comprehensive dataset of 500 brain cancer patients, including survival times, censoring status, and multiple clinical covariates. This dataset was used to demonstrate Accelerated Failure Time (AFT) regression and Cure-Rate models using the Beta-Danish distribution.

Usage

brain_cancer

Format

A data frame with 500 rows and 16 columns:

ID

Patient identifier

Gender

Patient gender (1 = Male, 0 = Female)

Age

Age group (1 = Young, 2 = Middle, 3 = Old)

Area

Geographic area (1 = Urban, 0 = Rural)

FH

Family history of cancer (1 = Yes, 0 = No)

CMH

Comorbid history (1 = Yes, 0 = No)

Grade

Tumor grade (1 = I/II, 2 = III, 3 = IV)

Surgery

Surgical intervention (1 = Yes, 0 = No)

Radiotherapy

Radiotherapy treatment (1 = Yes, 0 = No)

Chemotherapy

Chemotherapy treatment (1 = Yes, 0 = No)

Treatment

Treatment type

Morphology

Tumor morphology

Survstatus

Survival status (1 = Event/Death, 0 = Censored)

Survtime

Survival time in months

Types

Tumor types classification

Morphology1

Alternative morphology classification

Atomic Energy Cancer Hospital (NORI), Islamabad, Pakistan.

Examples

data(brain_cancer)

# Fit an AFT model using the brain cancer data
fit <- fit_bd_aft(survival::Surv(Survtime, Survstatus) ~ Age + Grade + Surgery,
                  data = brain_cancer, n_starts = 2)
summary(fit)


BetaDanish documentation built on May 20, 2026, 5:07 p.m.