| brain_cancer | R Documentation |
A comprehensive dataset of 500 brain cancer patients, including survival times, censoring status, and multiple clinical covariates. This dataset was used to demonstrate Accelerated Failure Time (AFT) regression and Cure-Rate models using the Beta-Danish distribution.
brain_cancer
A data frame with 500 rows and 16 columns:
Patient identifier
Patient gender (1 = Male, 0 = Female)
Age group (1 = Young, 2 = Middle, 3 = Old)
Geographic area (1 = Urban, 0 = Rural)
Family history of cancer (1 = Yes, 0 = No)
Comorbid history (1 = Yes, 0 = No)
Tumor grade (1 = I/II, 2 = III, 3 = IV)
Surgical intervention (1 = Yes, 0 = No)
Radiotherapy treatment (1 = Yes, 0 = No)
Chemotherapy treatment (1 = Yes, 0 = No)
Treatment type
Tumor morphology
Survival status (1 = Event/Death, 0 = Censored)
Survival time in months
Tumor types classification
Alternative morphology classification
Atomic Energy Cancer Hospital (NORI), Islamabad, Pakistan.
data(brain_cancer)
# Fit an AFT model using the brain cancer data
fit <- fit_bd_aft(survival::Surv(Survtime, Survstatus) ~ Age + Grade + Surgery,
data = brain_cancer, n_starts = 2)
summary(fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.