View source: R/competing_risks.R
| cif_betadanish | R Documentation |
Computes the CIF for a specific cause from a fitted Beta-Danish competing risks model using numerical integration.
cif_betadanish(fit, tvec, cause_idx)
fit |
An object of class 'bd_competing'. |
tvec |
Numeric vector of times at which to evaluate the CIF. |
cause_idx |
Integer; the specific cause to evaluate (must match one of the causes in the fitted model). |
A numeric vector of CIF probabilities corresponding to 'tvec'.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.